@@ -446,10 +446,10 @@ where
 pub unsafe trait RowSetBuffer {
     /// Declares the bind type of the Row set buffer. `0` Means a columnar binding is used. Any non
     /// zero number is interpreted as the size of a single row in a row wise binding style.
-    fn bind_type(&self) -> u32;
+    fn bind_type(&self) -> usize;
 
     /// The batch size for bulk cursors, if retrieving many rows at once.
-    fn row_array_size(&self) -> u32;
+    fn row_array_size(&self) -> usize;
 
     /// Mutable reference to the number of fetched rows.
     ///
@@ -469,11 +469,11 @@ pub unsafe trait RowSetBuffer {
 }
 
 unsafe impl<T: RowSetBuffer> RowSetBuffer for &mut T {
-    fn bind_type(&self) -> u32 {
+    fn bind_type(&self) -> usize {
         (**self).bind_type()
     }
 
-    fn row_array_size(&self) -> u32 {
+    fn row_array_size(&self) -> usize {
         (**self).row_array_size()
     }
 
